from __future__ import annotations


__all__ = (
    "SakiError",
    "BadStatusCodeError",
    "WikiNotFound",
    "BadContentRecievedError",
    "ParsingError",
)


class SakiError(Exception):
    """
    Base class for other exceptions.
    """

    __slots__ = ("error",)

    def __init__(self, error: str) -> None:
        self.error = error
        super().__init__(self.error)


class BadStatusCodeError(SakiError):
    """
    Raised when an unhealthy status code is recieved.
    """

    ...


class WikiNotFound(SakiError):
    """
    Raised when given character is not found.
    """

    ...


class BadContentRecievedError(WikiNotFound):
    """
    Raised when the content recieved is malformed.
    """

    ...


class ParsingError(SakiError):
    """
    Raised when some parser enounters any anomaly.
    """

    ...
